===============================
DjDT Flamegraph
===============================

Under construction...

.. image:: https://travis-ci.org/23andMe/djdt-flamegraph.svg?branch=master
        :target: https://travis-ci.org/blopker/djdt-flamegraph

.. image:: https://img.shields.io/pypi/v/djdt_flamegraph.svg
        :target: https://pypi.python.org/pypi/djdt_flamegraph

.. image:: https://raw.githubusercontent.com/23andMe/djdt-flamegraph/master/flamegraph-screenshot.png

Features
--------

* FLAMES
